@@ -10,21 +10,30 @@ import os
 import pathlib
 import re
 
+from loguru import logger
+
 from configmanager.config import Configuration
 
 
 class ConfigManager(object):
     # data
+    # moduleManager:ModuleManager|None
 
-    def __init__(self, file: str = '.commitclirc', config: Configuration = None, override_config: dict = None):
-        self._file = file
-        self.config = config
-        self.regex_clave_valor = r'[\D]+[=]{1}[\w]+'
+    def __init__(
+            self, file: str = '.commitclirc',
+            config: Configuration = None,
+            override_config:dict = None,
+        ) -> None:
+
+        self._file:str = file
+        self.config:Configuration = config
+        self.regex_clave_valor = r'[\D]+[=]{1}[\w.]+'
         self.pattern_regex_clave_valor = re.compile(self.regex_clave_valor)
 
         # some initial starts
         self.init_config(override_config=override_config)
 
+
     def current_file(self) -> str:
         """this function return the fullpath of the file to store
         the configuration
@@ -36,6 +45,7 @@ class ConfigManager(object):
         project_file = f"{pathlib.Path.cwd()}/{self._file}"
         return project_file if self.exist_file(project_file) else global_file
 
+
     def exist_file(self, file: str) -> bool:
         """this function returns a boolean value on true if the file
         to store the configuration
@@ -46,7 +56,8 @@ class ConfigManager(object):
         exist = os.path.exists(file)
         return True if exist else False
 
-    def stringline_to_key_value(self, string_line: str = "#comentario") -> str:
+
+    def stringline_to_key_value(self, string_line: str = "#comentario") -> tuple[str, str]:
         """This functions returns the separated values by '=' of a string in 
         format 'some=other'
 
@@ -61,8 +72,10 @@ class ConfigManager(object):
             elements = string_line.split("=")
             key= elements[0]
             value= elements[1]
+            logger.info(key, value)
         return key, value
 
+
     def load_file(self, file: str) -> dict:
         """Method to convert the configuration file into a dictionary
 
@@ -72,9 +85,9 @@ class ConfigManager(object):
         current_file = file
         if self.exist_file(current_file):
             data_dict = {}
-            file = open(current_file, 'r')
-            file_text = file.readlines()
-            file.close()
+            file_read = open(current_file, 'r')
+            file_text = file_read.readlines()
+            file_read.close()
             for file_line in file_text:
                 file_line = file_line.replace('\n', '')
                 key, value = self.stringline_to_key_value(string_line=file_line)
@@ -97,6 +110,7 @@ class ConfigManager(object):
         file.close()
         return True
 
+
     def init_config(self, force_reload: bool = False, override_config: dict = None) -> bool:
         """Method to initialize the class, triggering the load of the file or load
         creating a defaul config and save it on the file.
@@ -114,10 +128,12 @@ class ConfigManager(object):
                 self.config = Configuration(override_config=override_config)
                 self.save_file()
                 return False
+        print("config", self.config)
+        return False 
 
-    def get_config(self, name: str) -> str or bool:
+    def get_config(self, name: str) -> str or bool or None:
         if self.config is not None and self.config.config is not None and self.config.config[name] is not None:
             return self.config.config[name]
         else:
             return None
-        return None
+
